@@ -41,6 +41,7 @@ import sys
 
 
 from email.message import Message
+from errno import EACCES, EPERM
 from gettext import gettext as _
 from io import StringIO
 from optparse import (
@@ -1028,7 +1029,6 @@ def get_dpkg_log_content(logfile_dpkg, install_start_time):
 
 
 def main(options, rootdir=""):
-
     # useful for testing
     if rootdir:
         _setup_alternative_rootdir(rootdir)
@@ -1054,6 +1054,9 @@ def main(options, rootdir=""):
     # display available origin
     logging.info(_("Allowed origins are: %s") % allowed_origins)
 
+    # see debian #776752
+    install_start_time = datetime.datetime.now().replace(microsecond=0)
+
     # check if the journal is dirty and if so, take emergceny action
     # the alternative is to leave the system potentially unsecure until
     # the user comes in and fixes
@@ -1101,7 +1104,16 @@ def main(options, rootdir=""):
 
     # FIXME: make this into a ContextManager
     # be nice when calculating the upgrade as its pretty CPU intensive
-    os.nice(19)
+    old_priority = os.nice(0)
+    try:
+        # Check that we will be able to restore the priority
+        os.nice(-1)
+        os.nice(20)
+    except OSError as e:
+        if e.errno in (EPERM, EACCES):
+            pass
+        else:
+            raise
 
     # speed things up with latest apt
     actiongroup = apt_pkg.ActionGroup(cache._depcache)
@@ -1119,7 +1131,7 @@ def main(options, rootdir=""):
 
     # FIXME: make this into a ContextManager
     # stop being nice
-    os.nice(0)
+    os.nice(old_priority - os.nice(0))
 
     # download what looks good
     if options.debug:
@@ -1252,7 +1264,6 @@ def main(options, rootdir=""):
     # only perform install step if we actually have packages to install
     pkg_install_success = None
     shutdown_lock = -1
-    install_start_time = datetime.datetime.now()
     if len(pkgs_to_upgrade) > 0:
         # lock for the shutdown check - its fine if the system
         # is shutdown while downloading but not so much while installing
